#
# spec file for package kvm
#
# Copyright (c) 2012 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#
# icecream 0


%bcond_without spice

%define package_true_version 1.0
%define package_base_version 1.0
%define bios_id seabios-1.6.3
%define pxe_rom_id ipxe-git-aaf7a35
%define vgabios_id vgabios-0.6c
# sgabios comes from: http://sgabios.googlecode.com/svn/trunk, Rev 8
%define sgabios_id sgabios

# note that this list doesn't include the ipxe roms since they get handled
# individually and not as a group
%define firmware_files {bios.bin sgabios.bin vgabios.bin vgabios-cirrus.bin vgabios-stdvga.bin vgabios-vmware.bin vgabios-qxl.bin optionrom/linuxboot.bin optionrom/multiboot.bin optionrom/vapic.bin}

ExclusiveArch:  %ix86 x86_64 ia64 s390x

%ifarch %ix86 x86_64
# choice of building all from source or using provided binary x86 blobs
%define build_fw_from_source 1
%else
%define build_fw_from_source 0
%endif

%define using_buildservice 0%{?opensuse_bs}

Name:           kvm
BuildRequires:  SDL-devel
BuildRequires:  alsa
BuildRequires:  alsa-devel
BuildRequires:  glib2-devel
BuildRequires:  gnutls-devel
BuildRequires:  libaio-devel
BuildRequires:  libattr-devel
BuildRequires:  libcurl-devel
BuildRequires:  libpulse-devel
BuildRequires:  ncurses-devel
BuildRequires:  pciutils-devel
BuildRequires:  perl
BuildRequires:  python
BuildRequires:  texinfo
BuildRequires:  xfsprogs-devel
BuildRequires:  ceph-devel
%if 0%{?suse_version} >= 1130
BuildRequires:  brlapi-devel
%endif
%ifarch %ix86 x86_64 ia64
%if %{build_fw_from_source}
# needed for building vgabios:
BuildRequires:  bin86
%ifarch x86_64
#needed by bcc compiler which is needed for building vgabios:
BuildRequires:  glibc-32bit
%endif
%endif
%if 0%{?suse_version} > 1110
BuildRequires:  acpica
%else
BuildRequires:  pmtools
%endif
%endif
BuildRequires:  libvdeplug3-devel
%if %{with spice}
# Spice support requires pixman > 0.17, which does not included in older suse versions
%if 0%{?suse_version} >= 1130
# Spice support does not currently build with -Werror on 32-bit platforms
%ifnarch %ix86
BuildRequires:  libspice-server-devel
BuildRequires:  spice-protocol-devel
%endif
%endif
%endif
BuildRequires:  pwdutils
Requires:       pwdutils
Requires:       virt-utils
Requires:       python-curses
%if 0%{?suse_version} < 1110
Requires:       kvm-kmp
%endif
Summary:        Kernel-based Virtual Machine
License:        BSD-3-Clause ; GPL-2.0 ; GPL-2.0+ ; LGPL-2.1+ ; MIT
Group:          System/Kernel
Url:            http://www.linux-kvm.org
Version:        %{package_true_version}
Release:        4.3
Source0:        qemu-%{name}-%{package_true_version}.tar.bz2
Source1:        60-kvm.rules
Source2:        qemu-ifup
Source3:        kvm-supported.txt
Source4:        win-virtio-drivers.iso
Source5:        win-virtio-drivers-src.tar.bz2
Source6:        %{bios_id}.tar.bz2
Source7:        %{pxe_rom_id}.tar.bz2
Source8:        bcc-0.16.17-2.i486.rpm
Source9:        %{vgabios_id}.tar.bz2
Source10:       %{sgabios_id}.tar.bz2

# ipxe patches
Patch01:        ipxe-rom-settings.patch

# seabios patches
Patch20:        seabios-sanitize-version.patch

# vgabios patches
Patch40:        vgabios-bcc-paths.patch

# common and X86 patches
# qemu-kvm patches
Patch60:        qemu-datadir.diff
Patch61:        kvm-qemu-default-memsize.patch
Patch62:        kvm-qemu-user-space-tool-name.patch
Patch63:        kvm-qemu-madvise-DONTFORK-for-tight-memory-migration.patch

# Post-release upstream patches
Patch100:       kvm-qemu-preXX-dictzip1.patch
Patch101:       kvm-qemu-preXX-dictzip2.patch
Patch102:       kvm-qemu-preXX-report-default-mac-used.patch
Patch103:       kvm-qemu-preXX-console.patch
Patch104:       kvm-qemu-madvise-hugepages.patch
Patch105:       kvm-qemu-preXX-dictzip3.patch
Patch106:       kvm-qemu-preXX-g_thread_init-users-don-t-call-it-if-glib-2.31.patch
Patch107:       kvm-qemu-preXX-e1000-check-for-overflow-whenever-issuing-PCI-dma-reads.patch

Patch150:       qemu-kvm-common-code-fixes-for-s390-build.patch

Patch200:       qemu-img-vmdk-scsi.patch
Patch201:       kvm-studio-slirp-nooutgoing.patch
Patch202:       kvm-studio-vnc.patch

# for IA64
Source500:      ia64-fix-pagesize.pl
Patch500:       IA64-kvm-suse.patch
Patch501:       IA64-compile-fix-suse.patch

# for S390
Patch700:       S390-no-tpr.patch
Patch701:       S390-qemu-early-printk.patch
Patch702:       S390-0003-Make-char-muxer-more-robust-wrt-small-FIFOs.patch
Patch703:       S390-hp-0001--S390-Add-hotplug-support.patch
Patch704:       S390-hp-0002-Compile-device-hotplug-on-all-targets.patch
Patch705:       S390-hp-0003-Add-generic-drive-hotplugging.patch
Patch706:       S390-hp-0004-Expose-drive_add-on-all-architectures.patch

# For upstream patches:
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
PreReq:         /usr/sbin/groupadd

%description
KVM (Kernel-based Virtual Machine) is virtualization software for
Linux. It is based on the hardware virtualization extensions provided
by Intel VT and AMD-V technologies. KVM kernel modules provide a
control interface at /dev/kvm which the qemu-kvm user-space program
uses to provide a hybrid emulated and actual hardware environment
sufficent to run various PC operating systems (guests) in unmodified
form, including Linux, Windows, and Mac OS X.

Since qemu-kvm is derived from the qemu processor emulator sources it
also is able to run guests using processor emulation mode, but with the
expected performance impact. Conversely, hardware virtualization
features outside the processor such as iommu and sr-iov are used by KVM
allowing for improved performance.

The seabios, vgabios and ipxe open source projects are also pulled from
to provide the firmware components included.

To increase performance over emulated hardware devices virtio drivers
are supported, and in the case of Windows, included.

KVM is compatible with various VM management solutions, including
libvirt, virt-manager and vm-install.



Authors:
--------
    Avi Kivity   <avi@qumranet.com>
    Yaniv Kamay  <yaniv@qumranet.com>
    Dor Laor     <dor.laor@qumranet.com>

%prep
%if %{build_fw_from_source}
mkdir bcc-bits
cd bcc-bits/
rpm2cpio %{SOURCE8} | cpio -id ./usr/bin/bcc ./usr/lib/bcc/bcc-cc1
%setup -q -T -D -n %{pxe_rom_id} -b 7
# ipxe patches
%patch01 -p1
%endif
%setup -q -n qemu-%{name}-%{package_true_version} -a 6 -a 9 -a 10
%if %{build_fw_from_source}
#ensure that we only end up with the ones we built
for i in %firmware_files
do
  rm -f pc-bios/$i
done
# seabios patches
%patch20 -p1

# vgabios patches
%patch40 -p1
%endif

# qemu-kvm patches
%patch60 -p1
%patch61 -p1
%patch62 -p1
%patch63 -p1

# Post-release patches
%patch100 -p1
%patch101 -p1
%patch102 -p1
%patch103 -p1
%patch104 -p1
%patch105 -p1
%patch106 -p1
%patch107 -p1

%patch150 -p1

# Studio addons
%patch200 -p1
%patch201 -p1
%patch202 -p1

# IA64 support
%ifarch ia64
%patch500 -p1
%patch501 -p1
%endif
# S390 support
%ifarch s390x
%patch700 -p1
%patch701 -p1
%patch702 -p1
%patch703 -p1
%patch704 -p1
%patch705 -p1
%patch706 -p1
%endif

cp %{SOURCE3} .

%build
# change from devel version to actual version
echo "%{package_base_version}" > VERSION
echo "kvm-%{version}-%{release}" > KVM_VERSION
./configure \
        --prefix=%{_prefix} \
        --sysconfdir=%{_sysconfdir} \
        --extra-cflags="%{optflags}" \
        --disable-debug-tcg \
        --disable-sparse \
        --disable-strip \
        --enable-werror \
        --enable-sdl \
	--enable-rbd \
%if 0%{?suse_version} >= 1100
        --audio-drv-list="pa alsa sdl oss" \
%else
        --audio-drv-list="alsa sdl oss" \
%endif
        --audio-card-list="ac97 adlib cs4231a gus sb16 hda" \
%ifarch ia64
        --target-list="ia64-softmmu" --disable-cpu-emulation \
%else
%ifarch s390x
        --target-list="s390x-softmmu" \
%else
        --target-list="x86_64-softmmu" \
%endif
%endif
        --disable-xen \
        --enable-vnc-tls \
        --disable-vnc-sasl \
        --disable-vnc-jpeg \
        --disable-vnc-png \
        --disable-vnc-thread \
        --enable-curses \
        --enable-curl \
        --disable-fdt \
        --disable-bluez \
        --enable-kvm \
        --enable-kvm-pit \
        --enable-kvm-device-assignment \
        --disable-user \
        --enable-vde \
%if %{build_fw_from_source}
        --disable-blobs \
%endif
        --enable-docs \
%if 0%{?suse_version} == 1120
        --disable-linux-aio \
%else
        --enable-linux-aio \
%endif
%if 0%{?suse_version} >= 1130
        --enable-brlapi \
%if %{with spice}
%ifnarch %ix86
        --enable-spice
%endif
%endif
%else
        --disable-brlapi \
        --disable-spice
%endif

sed -i 's/CFLAGS  =/CFLAGS  +=/' roms/vgabios/Makefile
# userspace:
make %{?jobs:-j%jobs}

# Firmware
%ifarch %ix86 x86_64
%if %{build_fw_from_source}
make -C roms/seabios %{?jobs:-j%jobs}
cp roms/seabios/out/bios.bin pc-bios/bios.bin

make -C roms/sgabios
#make -C roms/sgabios %{?jobs:-j%jobs}
cp roms/sgabios/sgabios.bin pc-bios/sgabios.bin

make -C roms/vgabios %{?jobs:-j%jobs}
cp roms/vgabios/VGABIOS-lgpl-latest.bin pc-bios/vgabios.bin
cp roms/vgabios/VGABIOS-lgpl-latest.cirrus.bin pc-bios/vgabios-cirrus.bin
cp roms/vgabios/VGABIOS-lgpl-latest.stdvga.bin pc-bios/vgabios-stdvga.bin
cp roms/vgabios/VGABIOS-lgpl-latest.vmware.bin pc-bios/vgabios-vmware.bin
cp roms/vgabios/VGABIOS-lgpl-latest.qxl.bin pc-bios/vgabios-qxl.bin
cd ../%{pxe_rom_id}/src
make bin/8086100e.rom %{?jobs:-j%jobs}
make bin/10222000.rom %{?jobs:-j%jobs}
make bin/10500940.rom %{?jobs:-j%jobs}
make bin/10ec8139.rom %{?jobs:-j%jobs}
make bin/80861209.rom %{?jobs:-j%jobs}
make bin/1af41000.rom %{?jobs:-j%jobs}
%endif
%endif

%install
make DESTDIR=%{buildroot} install %{?jobs:-j%jobs}
mkdir -p %{buildroot}%{_docdir}/kvm
cp qemu-doc.html qemu-kvm.html
cp qemu-tech.html qemu-kvm-tech.html
install -m 755 kvm/kvm_stat %{buildroot}%{_bindir}/
%if %{build_fw_from_source}
for i in %firmware_files
do
  install -m 644 pc-bios/$i %{buildroot}%{_datadir}/qemu-kvm/
done
install_rom() {
  install -m 644 $1.rom %{buildroot}%{_datadir}/qemu-kvm/$2.rom
}
cd ../%{pxe_rom_id}/src/bin/
install_rom 8086100e pxe-e1000
install_rom 10222000 pxe-pcnet
install_rom 10500940 pxe-ne2k_pci
install_rom 10ec8139 pxe-rtl8139
install_rom 80861209 pxe-eepro100
install_rom 1af41000 pxe-virtio
%endif
cd %{buildroot}
rm -r .{%_bindir/qemu-io,%_bindir/qemu-nbd,%_datadir/doc/qemu}
mv .%_bindir/qemu-img{,-kvm}
%if !%{build_fw_from_source}
rm -r .%_datadir/qemu-kvm/{openbios-sparc32,openbios-sparc64,ppc_rom.bin,openbios-ppc,bamboo.dtb,petalogix-ml605.dtb,petalogix-s3adsp1800.dtb}
%endif
%ifarch ia64 s390x
rm .%_datadir/qemu-kvm/bios.bin
%endif
rm -r .%_mandir/man8/qemu-nbd.8
mv .%_bindir/{qemu-system*,qemu-kvm}
mv .%_mandir/man1/{qemu.1,qemu-kvm.1}
mv .%_mandir/man1/{qemu-img.1,qemu-img-kvm.1}
chmod 644 .%_mandir/man1/*
install -D -m 644 %{SOURCE1} %{buildroot}/etc/udev/rules.d/60-kvm.rules
install -D -m 755 %{SOURCE2} %{buildroot}/usr/share/qemu-kvm/qemu-ifup
install -D -m 644 %{SOURCE4} %{buildroot}/usr/share/qemu-kvm/win-virtio-drivers.iso

%clean
cd ../
rm -rf bcc-bits
rm -rf %{pxe_rom_id}
rm -rf $RPM_BUILD_ROOT

%pre
%{_bindir}/getent group kvm >/dev/null || %{_sbindir}/groupadd -r kvm 2>/dev/null
%{_bindir}/getent group qemu >/dev/null || %{_sbindir}/groupadd -r qemu 2>/dev/null
%{_bindir}/getent passwd qemu >/dev/null || \
  %{_sbindir}/useradd -r -g qemu -G kvm -d / -s /sbin/nologin \
  -c "qemu user" qemu

%files
%defattr(-,root,root)
%doc qemu-kvm.html qemu-kvm-tech.html kvm-supported.txt
%attr(755,root,kvm) %{_bindir}/qemu-kvm
%attr(755,root,kvm) %{_bindir}/qemu-img-kvm
%attr(755,root,kvm) %{_bindir}/qemu-ga
%attr(755,root,kvm) %{_bindir}/kvm_stat
%{_datadir}/qemu-kvm
%dir %attr(0755, root, kvm) %{_sysconfdir}/qemu-kvm/
%config %attr(644,root,kvm) %{_sysconfdir}/qemu-kvm/target-x86_64.conf
%config %{_sysconfdir}/udev/rules.d/60-kvm.rules
%_mandir/man1/qemu-kvm.1.gz
%_mandir/man1/qemu-img-kvm.1.gz

%changelog
* Wed Feb 15 2012 hmacht@suse.de
- Build with support for rbd
* Mon Jan 23 2012 brogers@suse.com
- avoid buffer overflow in e1000 device emulation (bnc#740165)
* Wed Jan 11 2012 brogers@suse.com
- fix issue with g_thread_init deprecation now treated as error
* Tue Dec 13 2011 bkutil@suse.com
- Fix dictzip with long file names.
* Tue Dec 13 2011 brogers@suse.com
- Update to qemu-kvm v1.0
  - see http://wiki.qemu.org/ChangeLog/1.0 for details
* Tue Nov 29 2011 brogers@suse.com
- change a build dependency from spice-devel to spice-protocol
* Mon Nov 28 2011 brogers@suse.com
- add missing break. Plugs potential buffer overflow in CCID card
  passthru device (bnc#731086)
* Wed Oct 26 2011 brogers@suse.com
- Update to qemu-kvm v0.15.1
  - see http://wiki.qemu.org/ChangeLog/0.15 for details
- update to most recent ipxe upstream development sources
* Mon Oct 10 2011 brogers@suse.com
- Update seabios to v1.6.3
- fix curl based disk access
- fix termination by signal with -no-shutdown option set
- dont set e1000 capabilities list bit
* Thu Sep 15 2011 brogers@suse.com
- take advantage of Transparent Huge Pages on host
- include sgabios.bin
* Thu Aug 25 2011 brogers@novell.com
- update to v0.15.0
  for details, see: http://wiki.qemu.org/ChangeLog/0.15
- update to latest seabios (ahci is enabled there now)
- fix failures migrating or saving large memory vms when remaining
  host memory is insuffienct (bnc#705095)
- fix for creating 1MB vm
* Thu Aug 25 2011 brogers@novell.com
- fix build: don't use deprecated functions
* Mon Aug  1 2011 brogers@novell.com
- update to v0.15.0 rc1
- update to latest ipxe and seabios upstream development sources
- build seabios with ahci support enabled
- add a BuildRequires for xfsprogs-devel so trim/discard is enabled
  for raw images.
- add braile support
- enable linux AIO
- pulse audio is now first in list - making it the default interface
* Thu Jul 14 2011 agraf@suse.de
- fix RAM limit on s390x (bnc#689081)
- automatically load kvm kernel module on s390x (bnc#691668)
- make dzip big-endian safe (bnc#692217)
- fix potential endless loop in dictzip (bnc#693592)
- update s390 patches to fit with 0.15
* Fri Jul  8 2011 brogers@novell.com
- validate virtqueue indirect descriptor against max size
  (bnc#701161)
* Wed Jul  6 2011 brogers@novell.com
- fix possible out of bounds memory access (bnc#702823)
* Tue Jun  7 2011 brogers@novell.com
- added creation of user/group qemu/qemu for use by libvirt (and
  potentially others) to avoid running as root
* Thu May 19 2011 andrea@opensuse.org
- clean up buildrequires removing unsed vde libraries packages
* Wed May 18 2011 brogers@novell.com
- update to version 0.14.1
  includes patches we already carry, also the following fixes:
  qed consistency check
  use after free issue with drive_del
  device assignment issue
  emulated scsi adapter ABORT message handling
  applesmc REV key
  handling of vhostforce parameter to -net
  allow ISA IRQ sharing
* Tue May 17 2011 mhopf@novell.com
- Add libattr-devel to BuildRequires for OS11.3 and up (required for -virtfs).
* Sun May 15 2011 andrea@opensuse.org
- enabled vde2 support
* Thu May 12 2011 brogers@novell.com
- cleanup unused variable (for gcc4.6) and extra whitespace from
  block/dictzip.c
- lots of other code cleanup related to gcc4.6 flagging variables
  which are set but not otherwise used. Some of these were taken
  from the ipxe project and applied to our gpxe code.
* Tue May 10 2011 brogers@novell.com
- building for spice made conditional
* Wed May  4 2011 brogers@novell.com
- Update seabios to version 0.6.2
- put pulse audio first in sound interface list
- various upstream post 0.14 fixes, including:
  abort on bad drive command-line parameters
  vnc crash upon too much output
  various vnc issues
  various virtio issues
  various e1000 issues
  performance regression
  multiwrite
* Sun Apr 10 2011 aevseev@gmail.com
- build with spice support for newer suse versions on x86_64
* Mon Mar 21 2011 brogers@novell.com
- re-enable Linux AIO for SLE11 build
- let vhost-net support be determined by build environment
- add sb16 and hda sound card support (hda is new as of 0.14)
- e1000 fix (bnc#626654)
- upstream fixes for device-asignment, pc-net, sd memory, vnc
  memory leak, vnc crash, potential deadlock
* Fri Feb 25 2011 brogers@novell.com
- disable vnc threading due to memory leak (bnc#671809)
* Wed Feb 23 2011 bwiedemann@novell.com
- fix building with vde
* Tue Feb 22 2011 brogers@novell.com
- update to version 0.14.0
  See http://wiki.qemu.org/Changelog/0.14 for changes in 0.14
  upstream qemu. Also includes kvm-specific enhancements.
* Mon Feb 21 2011 brogers@novell.com
- update to latest pre 0.14.0 rc. (Includes the qemu 0.14.0 code as
  a basis)
- more parallel makes
* Thu Feb 10 2011 brogers@novell.com
- update to rc1 of qemu-kvm version 0.14.0
- provide missing video bios files (bnc#669912)
- fix issues with using i82559er emulated nic
- be explicit about more configure options
- enable vnc threading
* Sat Feb  5 2011 brogers@novell.com
- update to rc0 of qemu-kvm version 0.14.0. A more complete list of
  changes will follow with the official release, but here are some
  highlights:
  - virtio improvements
  - ahci emulation
  - stable QMP interface
  - better spice support
  - block device resizing
  - huge nbd performance improvement
  - qed disk image format (new)
  - qcow2 performance and stability improvements
  - many bug fixes
- update to version 0.6.1.2 of Seabios
- fix buffer overrun in slirp
* Sat Jan 15 2011 brogers@novell.com
- update gpxe roms to version 1.0.1
- tweak braille support
* Fri Jan 14 2011 bwiedemann@novell.com
- add braille support
* Fri Jan  7 2011 brogers@novell.com
- Fix mouse breakage (bnc#660870)
* Fri Jan  7 2011 brogers@novell.com
- [dictzip] fix images > 32bit (Alexander Graf) (bnc#654944)
* Tue Nov 30 2010 brogers@novell.com
- fix virtio-blk failure after reboot
* Mon Nov  1 2010 brogers@novell.com
- Update to stable release 0.13.0. Includes:
  - vhost-net: kernel-accelerating network backend for virtio devices
  - qmp: significant improvements covering most monitor commands
  - vnc: introduction of new encodings that dramatically improve bandwidth
  - ivshmem: new shared memory device allowing multiple guests to share
    a memory region
  - mips: introduction of fulong mini-pc
  - virtio-9p: introduction of a paravirtual file system passthrough
    mechanism
  - hpet: many enhancements
  - target-s390: support for s390 usermode emulation
  - QMP is still considered experimental in 0.13.0, but should be usable by
    libvirt
- SeaBios updated to 0.6.1. Includes:
  - Support for virtio drives
  - Add ACPI definitions for cpu hotplug support
  - Support for a graphical bootsplash screen
  - USB mouse support
  - The PCI support for emulators is less dependent on i440 chipset
* Mon Oct  4 2010 brogers@novell.com
- Change default memory from 384MB to 512MB, which is in keeping
  with the default used by vm-install. This increased amount allows
  more guest configurations to be usable without specifying the
  memory. (bnc#640093)
- Fix building gpxe when using latest make tool.
* Mon Sep 27 2010 brogers@novell.com
- Revert writeback cache change until we can resolve the issues
  discovered in bnc#637297
* Thu Jul 29 2010 brogers@novell.com
- Update to stable release 0.12.5, which includes numerous bug
  fixes. This and other recent changes address: bnc#598298,
  bnc#621793, bnc#619991, bnc#603179
- Warn if default mac address is used
- rtl8139 stops working after restore
- Incompatibility with libvirt if disk caching specified in xml
* Mon Jul 19 2010 brogers@novell.com
- qemu-kvm was mistakenly being built without libaio support, which
  results in less efficient disk i/o (bnc#598271)
* Tue Jun 15 2010 brogers@novell.com
- Fix "hang" in bios seen with recent isolinux (bnc#603161)
* Wed Jun  2 2010 agraf@suse.de
- Fix multiboot (bnc#610682)
* Tue Jun  1 2010 agraf@suse.de
- Pull in some patches that are in the 0.12.5 stable queue. I only picked
  the ones that looked pretty serious (and affected us).
* Tue Jun  1 2010 agraf@suse.de
- Pull in some block speedup patches from me (bnc#599095). This also
  changes the default for block devices back to writeback, which should
  significantly speed up default block assignments.
* Thu May 13 2010 brogers@novell.com
- There are various issues in the multiwrite code paths for which
  upstream patches already exist, including a bad memory leak.
  This addresses bnc#603523. These patches are now included:
  kvm-qemu-pre0.12.4-fix-multiwrite-error-code.patch
  kvm-qemu-pre0.12.4-fix-multiwrite-error-handling.patch
  kvm-qemu-pre0.12.4-fix-multiwrite-memory-leak.patch
  kvm-qemu-pre0.12.4-free-iovec-array.patch
* Mon May 10 2010 brogers@novell.com
- Windows virtio iso filename clarification (bnc#603900)
- Document warning about using the default mac address (bnc#603179)
- Clarify pci passthrough support statement
* Tue Apr 27 2010 brogers@novell.com
- Fixed block io corruption bug where we weren't watching to not
  exceed IOV_MAX. (bnc#586118, bnc#599012)
* Mon Apr 26 2010 brogers@novell.com
- Update windows virtio drivers to latest available (incl. Balloon)
- Included Windows XP and 2003 install fix for isa-pc case as well
  (bnc#590683)
- Add -boot option for -drive parm to the doc. (bnc#594742)
- Improved formatting of kvm-supported.txt file
* Tue Apr 20 2010 agraf@suse.de
- Update S390 zipl loader - now works without guest modifications
* Sat Apr 10 2010 brogers@novell.com
- Proper fix for Windows XP and 2003 install problems (bnc#590683)
- gpxe compiles more cleanly
- report error if monitor change command fails
* Wed Apr  7 2010 agraf@suse.de
- Pull in patches that are waiting for 0.12.4 to be released
  - Fixes overlapping rom regions (bnc#590425)
  - Give warning instead of segfault with -smp > max (bnc#581712)
- Add S390 patches to make -nographic work properly and add
  bootloader code
- Fix cmos patch to enable S390 building again
* Fri Mar 26 2010 brogers@novell.com
- in no-kvm mode, enforce RAM limit of 4095 MB  (bnc#581738)
- fix floppy support using -global isa-fdc (bnc#591597)
* Fri Mar 26 2010 brogers@novell.com
- Windows XP and 2003 install again when using -device w/ide (bnc#590683)
- fix segfault when guest started with > 16 vcpus (bnc#581712)
- balloon info in monitor is erratic/incorrect (bnc#580841)
- removed --allow-unsupported-modules from modprobe (bnc#588214)
- updated kvm-supported.txt
* Tue Mar 16 2010 brogers@novell.com
- add file kvm-supported.txt to document supported features
* Wed Mar 10 2010 brogers@novell.com
- Update to 0.12.3, which includes these changes among others:
  - segfault due to buffer overrun in usb-serial
  - kvm: Fix eflags corruption in kvm mode
  - don't dereference NULL after failed strdup
  - better error handling in storage code
  - virtio-net: fix network stall under load
- Fix hang in bios with multiple vcpus (bnc#586260)
- Cherry picked a few other useful upstream post 0.12.3 fixes
* Fri Mar  5 2010 coolo@novell.com
- do not put 11 chars in a direntry with only length of 8
  (I hope upstream comes up with something better soon)
* Mon Mar  1 2010 agraf@suse.de
- Add Studio specific patches back again
  - VNC password file
  - VNC exit after n disconnects
  - SLIRP disable outgoing connections
* Mon Mar  1 2010 agraf@suse.de
- Hotfix to get hotplug with virtio work again (bnc#583696)
* Wed Feb 24 2010 agraf@suse.de
- Get qemu-img-kvm back (really important for Studio!)
* Fri Feb 19 2010 brogers@novell.com
- Fix network booting (bnc#580947)
- Fix virtio network shutdown under load
- Fix buffer overrun
- Fix access after end of array
- Cleanup issues with net device integration
- Fix remaining extraneous stderr output on startup
* Tue Feb 16 2010 agraf@suse.de
- Implement long file names for tar (bnc#580100)
* Wed Jan 20 2010 brogers@novell.com
- Update to 0.12.2, including these changes among others:
  - Update SeaBIOS to 0.5.1
  - vnc: Fix artifacts in hextile decoding
  - device assignment: default requires IOMMU
  - pc: add machine type for 0.12
  - Fix CPU topology initialization
  - vmware_vga: Check cursor dimensions to avoid buffer overflow
- Remove deprecated windows drivers
- ability to build all objects from source now
- build debug package
* Mon Jan 18 2010 agraf@suse.de
- Make dzip not consume endless amounts of ram (bnc#569337)
* Wed Jan 13 2010 agraf@suse.de
- Make block-tar work for images > 8 GB (bnc#565600)
* Tue Jan  5 2010 brogers@novell.com
- update to 0.12.1.2 (FATE#306513)
  Changes from qemu-kvm-0.11.x include:
  - merge qemu 0.12.1
  - many changes, including:
  - s390 support
  - live migration: support migration with non shared storage
  - live migration: make save/restore data driven (VMState)
  - monitor: introduce machine-protocol (QMP)
  - qdev: convert many devices, support reading config from file
  - pci: infrastructure to support 64-bit busses
  - net: introduce -netdev to support point-to-point networking
  - net: add support for GSO and checksum offload
  - tons of bug fixes throughout the code base
  - many kvm-specific bug fixes
* Tue Dec  8 2009 agraf@suse.de
- enable S390 target which is now upstream (FATE#306513)
* Mon Dec  7 2009 agraf@suse.de
- update to 0.12.0-rc0 (FATE#306513)
  - detailed changes following on -rc1
* Fri Dec  4 2009 brogers@suse.de
- added latest windows virtio drivers to package
  previous version of drivers is deprecated
* Thu Nov 12 2009 brogers@suse.de
- Fix package dependencies (bnc#554850)
* Sat Nov  7 2009 brogers@suse.de
- update package description
* Mon Oct 19 2009 agraf@suse.de
- fix incorrect search in /usr/share/qemu (#534850)
* Mon Sep 28 2009 brogers@novell.com
- update to 0.11.0
  Changes from the qemu-kvm-0.10 series:
  - merge qemu 0.11.0
  - qdev device model
  - qemu-io
  - i386: multiboot support for -kernel
  - gdbstub: vCont support
  - i386: control over boot menu
  - i386: pc-0.10 compatibility machine type
  - qcow2: use cache=writethrough by default
  - i386: MCE emulation
  - i386: host cpuid support
  - slirp: host network config
  - virtio: MSI-x support
  - pci: allow devices to specify bus address
  - migration: allow down time based threshold
  - virtio-net: filtering support
  - http block device support
  - i386: expose numa topology to guests
  - native preadv/pwritev support
  - kvm: guest debugging support
  - vnc: support for acls and gssapi
  - monitor: allow multiple monitors
  - device assignment: MSI-X support (Sheng Yang)
  - device assignment: SR/IOV support (Sheng Yang)
  - irqfd support (Gregory Haskins)
  - drop libkvm, use some of the upstream kvm support (Glauber Costa)
  - device assignment: option ROM support (Alex Williamson)
  - x2apic support (Gleb Natapov)
  - kvm/msi integration (Michael S. Tsirkin)
  - hpet/kvm integration (Beth Kon)
  - mce/kvm ingration (Huang Ying)
- refresh patch series
* Fri Sep 25 2009 brogers@novell.com
- fix qemu-kvm crash due to buffer overrun (bnc#537387)
* Wed Sep  9 2009 agraf@suse.de
- Update to 0.11.0-rc2
  - no changelog provided upstream, will hopefully follow for 0.11.0
- Include Mac OS X patches again
- Include dictzip patches (Studio related)
- Split KMP out, we'll take the kernel module as of now
- Version update in accordance with fate#306665
* Thu Aug  6 2009 agraf@suse.de
- Fix IA64 build
* Wed Jul 29 2009 agraf@suse.de
- update kvm-78 -> qemu-kvm-0.10.5
  - 'info chardev' monitor command
  - automatic port allocation for vnc and similar
  - improved cdrom media change handling
  - scsi improvements
  - e1000 vlan offload
  - fix interrupt loss when injecting an nmi
  - SPT optimizations
  - x86 emulator improvements
  - fix amd->intel migration
  - enable virtio zero-copy (Mark McLoughlin)
  - uuid support
  - hpet support
  - '-drive serial=...' option
  - improved tsc handling (Marcelo Tosatti)
  - guest S3 sleep (Gleb Natapov)
  - '-no-kvm-pit-reinjection' option to improve timing on RHEL 3 era guests (Marcelo Tosatti)
  - fix xen-on-kvm
  - enable ac97 audio by default
  - add virtio-console device
  - fix rtc time drift on Windows (-rtc-td-hack option)
  - vnc improvements
  - fix kvmclock on hosts with unstable tsc (Gerd Hoffman)
  - fix cygwin on Windows x64
- enable nested paging again
* Mon May 25 2009 agraf@suse.de
- make SLES9 kernel work with -kernel (#458258)
- add patches to get Xen running as guest
* Sat Feb 21 2009 agruen@suse.de
- Remove the dependency on kernel-source-rt and kernel-syms-rt:
  those -rt packages will not ship in their current versions.
* Mon Jan 26 2009 agraf@suse.de
- add Windows 7 and Vista fix for userspace networking
* Fri Jan 16 2009 agraf@suse.de
- disable SLERT build for < 11.1
- backport virtio performance tweaks (bnc#466743)
- remove MSR debug message that clutters the log
- include kvm_stat tool to ease debugging
* Tue Jan 13 2009 dgollub@suse.de
- prepared for multi kernel variant build
  - use kernel variant specific kernel source directory instead of
    the symlinked kernel source directory
- added kernel-syms-rt to build requires to build SLERT KMPs
* Wed Jan  7 2009 agraf@suse.de
- update driver CD
- apply security bugfixes:
  - slirp buffer overflow (CVE 2007-5729)
  - VNC DoS (bnc#464142, CVE-2008-2382)
  - VNC password guessing (bnc#464141, CVE-2008-5714)
* Tue Dec 16 2008 agraf@suse.de
- upstream backports:
  - fix NMI injection issues (#458642)
  - MMU speedups and fixes (#448114)
  - fix bug in memory slot assignment
  - makes our kmp work with current svn qemu
  - fix buffer overflow in cirrus buffer (#448551)
- AltGr on VNC fix (#450148)
- add release to sysfs version (#450571)
- do not emulate CPUs if opening /dev/kvm failed (#458910)
* Mon Dec  1 2008 agraf@suse.de
- update OSX patch to work for kvm-78
* Fri Nov 21 2008 brogers@novell.com
- revert disk caching mode back to writeback for now.
* Sat Nov  8 2008 agraf@suse.de
- fix external buildservice compilation
* Fri Nov  7 2008 agraf@suse.de
- fix compilation for < 11.1
* Thu Nov  6 2008 brogers@novell.com
- make qemu-ifup script executable
* Thu Nov  6 2008 brogers@novell.com
- allow autoloading to handle our KMP unsupported status
- add a default qemu-ifup script for bridged configuration
* Wed Nov  5 2008 agraf@suse.de
- update to KVM 78
  - fix nmi watchdog emulation (Jan Kiszka)
  - merge qemu-svn
  - new live migration implementation
  - usb improvements
  - migration fixes
  - read UUID from qemu (Gleb Natapov)
  - increase max cpu count to 255 for ia64 (Xiantao Zhang)
  - fix some AMD->Intel live migration failures
  - increase rmap preallocation (Marcelo Tosatti)
  - fixes oops on mmu intensive smp workloads
  - update e820 table for ept real mode identity map page (Sheng Yang)
- add autoloading of KVM modules
- do not block other VMMs when KVM is loaded
* Thu Oct 23 2008 brogers@novell.com
- misc cleanup and again address s390 build
* Thu Oct 23 2008 brogers@novell.com
- fix build failures in check-gcc-output
* Fri Oct 17 2008 agraf@suse.de
- update to KVM 77
  - improved usb support
  - vnc improvements
  - pass uuid to guest
  - scsi/virtio improvements
  - improve debugging support
  - improve >4GB memory support (Alex Williamson)
  - fix ia64 boot with acpi enabled (Xiantao Zhang)
  - fix ia64 with >= 3GB RAM (Xiantao Zhang)
  - fix live migration
  - kernel support for device assignment
    (Allen Kay, Amit Shah, Weidong Han, Ben-Ami Yassour)
  - improved NMI support (Jan Kiszka)
- add driver kit to /usr/share/qemu-kvm
- fix issues with our new 2.6.27 kernels
- set default RAM size to 384MB
* Wed Oct  1 2008 rw@suse.de
- reflect move to 64k page size on ia64  (bnc#429881)
- fix build for ia64
* Mon Sep 22 2008 lnussel@suse.de
- optionally build with vde support
- require gnutls to enable vnc tls support
* Tue Sep 16 2008 brogers@novell.com
- Fix build for ia64 and first attempt for s390
  - bnc#353836: s390 source now GPLv2
* Tue Sep 16 2008 agraf@suse.de
- update to KVM 75
  - ballooning (Anthony Liguori)
  - requires 2.6.27+ host to work correctly
  - fixes extboot failures after reset
  - fixes rare reboot failures with Windows
  - fixes ACPI error messages in Windows event log
  - fixes hibernate/resume with guest smp
  - fix random segfaults with npt (Joerg Roedel)
- enable building on 10.3 again
* Thu Sep  4 2008 agraf@suse.de
- update to KVM 74
  - fix shadow ptes corruption on i386 hosts running smp guests
  - improved usb support
  - usb auto connect/disconnect
- add IA64 support
- spec file cleanup
* Fri Aug 22 2008 agraf@suse.de
- fix the PulseAudio disabling for older distributions
* Thu Aug 21 2008 agraf@suse.de
- update to KVM 73
  - improve qcow2 performance with cache=off
  - ide fixes
  - external module compatibility with 2.6.27 hosts
  - virtio-net speedup (Mark McLoughlin)
  - support Windows hibernation on non-FlexPriority hosts
  - full swapping support (Andrea Arcangeli)
  - needs 2.6.27 hosts
  - paravirt guest: query tsc frequency from host (Glauber Costa)
  - fix debug register corruption on Intel hosts (Marcelo Tosatti)
  - fix -no-kvm-irqchip
* Wed Aug 20 2008 agraf@suse.de
- fix the PulseAudio disabling for older distributions
* Tue Aug 19 2008 brogers@novell.com
- change kernel module install location from weak-updates to updates
  as per email received from Peter Bowen (pzb@novell.com).
* Tue Aug 19 2008 agraf@suse.de
  Temporary fixes for NPT breakage:
  - Disabled nested paging by default
  - When nested paging is enabled, make it slow but reliable
* Wed Jul 30 2008 agraf@suse.de
- update to KVM 72
  - fixes suspend/resume of multiple nics
  - adds Virtual Distributed Ethernet (vde) support
  - avoid losing the iothread on random signals
  - add 'info kvm' monitor command  (Anthony Liguori)
  - avoid tpr patching when the stack is not valid (Marcelo Tosatti)
  - fixes some variant of Windows 2003 SMP
  - fix extboot stomping on reserved interrupt vectors (H. Peter Anvin)
  - MMU improvements
  - fix interrupt reinjection in real mode (Jan Kiszka)
  - x86 hardware task switching fixes (Marcelo Tosatti)
  - fix interrupts being delayed by instruction emulation
  - improves Vista stability
  - ignore no-op DEBUGCTL msr writes (Alexander Graf)
  - fixes Netware
- fix running of 32-bit code in x86_64 SLES10SP2 (bnc#403189)
- make /usr/bin/qemu-kvm runnable as non kvm group member
- take out the vmi fix again, as that's fixed upstream
* Tue Jul 22 2008 agraf@suse.de
- disable PulseAudio for older distributions, so the
  package still builds on < 11.0
* Tue Jul 15 2008 agraf@suse.de
- update to KVM 71
  - virtio fixes
  - adds pulseaudio driver
  - fix lost interrupt when changing a device irq
  - fix host msr corruption when host preempt is enabled
  - fix kvmclock (Gerd Hoffmann, used in xenner)
  - allow Linux 2.6.9 guests to boot
  - fix booting guests compiled with gcc 4.3
  - fix ioapic hang on heavy load (Mark McLoughlin)
  - fix suspend/resume on AMD (Joerg Roedel)
- enable PulseAudio support
* Wed Jul  9 2008 agraf@suse.de
- add support for VMI-enabled kernels
* Wed Jun 25 2008 agraf@suse.de
- update to KVM 70
  - improve virtio net performance (Anthony Liguori)
  - fix corrupted breakpoints (Jerone Young)
  - fix debugging (Jan Kiszka)
  - add mtrr support
  - merge qemu-svn
  - remove dependency on gcc 3
  - vnc client segfault fix
  - fix vnc problems on resize
  - enable tpr optimization for smp
  - should drastically speed up Windows XP SMP guests
  - fix false flooding when a pte points to a page table
  - improves 2.4 pae guests with CONFIG_HIGHPTE
  - enable NMI support on Intel (Sheng Yang)
  - fix hypercall return value on AMD
  - fixes running CONFIG_KVM_GUEST guests
  - allow VMware Server to take over vmx when unloading the module (Eli Collins)
  - fix crash on resume from suspend to ram (Andrea Arcangeli)
  - emulator improvements
- Snow Leopard compatibility fixes
- reenable CPU emulation
* Thu Jun  5 2008 agraf@suse.de
- update to KVM 69
- update to latest Mac patches
* Mon May 26 2008 agraf@suse.de
- enable ALSA
* Fri Mar 28 2008 coolo@suse.de
- adding ncurses-devel to buildrequires
* Fri Mar  7 2008 bk@suse.de
- Update to kvm-63, adds curses interface. It still uses gcc for qemu's
  CPU emulation which is broken with gcc4 -> disable it temporarily.
* Mon Feb 25 2008 alex@suse.de
- Fix cpuid patch
* Thu Feb 21 2008 bk@suse.de
- Add fixes from upstream and drop cpuidfake patch, fixes bnc#360671
* Fri Feb 15 2008 bk@suse.de
- Update to kvm-61, adds paravirtualized clock and dozens of fixes
- Fix cpuid asm or 64-bit guest support and fix core duo support
- Build the BIOS images from source and add ACPI entries for -M mac
- Build qemu with -O0 to work around real-mode emulation problems
* Fri Feb 15 2008 agraf@suse.de
- Include fix to make gfxboot work on Intel
* Wed Feb 13 2008 anschneider@suse.de
- Add upstream patch to fix VMs that no longer boot
* Thu Jan 24 2008 bk@suse.de
- Update to kvm-60, add C2D cpuid level 4, use bios.mac for -M mac
* Fri Jan 11 2008 bk@suse.de
- Update to kvm-59, now works with gfxboot of recent openSUSE CDs!
* Tue Aug 28 2007 bk@suse.de
- based unpon version in opensue buildservice by dbahi/kraxel
